@@ -20,19 +20,12 @@ def install_openapi_auth(app: FastAPI) -> None:
                     "type": "oauth2",
                     "flows": {"password": {"tokenUrl": "/auth/login", "scopes": {}}},
                 },
-                # JWT-in-cookie (your session token)
                 "SessionCookie": {"type": "apiKey", "name": st.auth_cookie_name, "in": "cookie"},
-                # API keys for service-to-service calls
                 "ApiKeyHeader": {"type": "apiKey", "name": "X-API-Key", "in": "header"},
             }
         )
 
-        # Make credentials optional but available for all operations by default.
-        schema["security"] = [
-            {"OAuth2PasswordBearer": []},
-            {"SessionCookie": []},
-            {"ApiKeyHeader": []},
-        ]
+        # IMPORTANT: do NOT set schema["security"] here.
 
         app.openapi_schema = schema
         return schema
