@@ -1,9 +1,9 @@
 from .dualize import dualize_protected, dualize_public, dualize_service, dualize_user
 from .protected import (
-    api_service_router,
-    optional_principal_router,
+    optional_identity_router,
     protected_router,
     roles_router,
+    service_router,
     user_router,
 )
 from .public import public_router
@@ -17,8 +17,8 @@ __all__ = [
     "dualize_service",
     "public_router",
     "protected_router",
-    "optional_principal_router",
+    "optional_identity_router",
     "user_router",
-    "api_service_router",
+    "service_router",
     "roles_router",
 ]
